@@ -16,22 +16,21 @@
 
 ## ----eval=TRUE, echo=FALSE, results="asis"-------------------------------
 # Load the RDML package for reading of the hookreg.rdml-file from the PCRedux
-# package. The magrittr package is used for pipes.
+# package.
 
 library(RDML)
 library(PCRedux)
-library(magrittr)
 
-# A comprehensive description of the RDML-file import can be found in Rödiger 
+# A comprehensive description of the RDML-file import can be found in Roediger 
 # et al. (2017) Bioinformatics
 
 raw_data <- RDML$new(filename=system.file("hookreg.rdml", package="PCRedux"))
 
 raw_data_tab <- raw_data$AsTable(name.pattern=paste(
-    react$position,
-    react$sample$id,
-    # run id added to names
-    sep="~"))
+  react$position,
+  react$sample$id,
+  # run id added to names
+  sep="~"))
 data <- as.data.frame(raw_data$GetFData(raw_data_tab, long.table=FALSE))
 
 ## ----ampcurves,fig.width=7.25, fig.height=9.25, echo=TRUE, message=FALSE, warning=FALSE, fig.cap="Amplification curves. A) Synthetic template, detected with Syto-13. B) Human \\textit{MLC-2v}, detected with a hydrolysis probe. C) \\textit{S27a} housekeeping gene, detected with SybrGreen I. D) Whole genome amplification, detected with EvaGreen. E) Human \\textit{BRCA1} gene, detected with a hydrolysis probe. F) Human \\textit{NRAS} gene, detected with a hydrolysis probe. G) Water control, detected with a hydrolysis probe. See Table \\ref{Table_human_rated} for details. RFU, relative fluorescence units. \\label{ampcurves}"----
@@ -80,29 +79,28 @@ samples names, data source (origin of data either from an existing data set or
 prepared for this study), the detection chemistries (intercalator (Syto-13, 
 SyberGreenI, EvaGreen), hydrolysis probes (TaqMan (Cy5/BHQ2) , TaqMan 
 (HEX/BHQ1))) and calculations by tow humans.", 
-             label='Table_human_rated'),
-      size = "\\tiny",
-      include.rownames = FALSE,
-      include.colnames = TRUE,
-      caption.placement = "top",
-      comment=FALSE,
-      table.placement = "!ht", scalebox='0.65'
+label='Table_human_rated'),
+size = "\\tiny",
+include.rownames = FALSE,
+include.colnames = TRUE,
+caption.placement = "top",
+comment=FALSE,
+table.placement = "!ht", scalebox='0.65'
 )
 
 ## ---- echo=TRUE, message=FALSE, warning=FALSE----------------------------
 # Load PCRedux package to obtain the data and make the hookreg() function
 # available.
 library(PCRedux)
-# Load the magrittr to use the %>% pipe-operator
-library(magrittr)
 
 # `data` is a temporary data frame of the hook.rdml amplification curve data file.
 # Apply the hookreg() function over the amplification curves and arrange the 
 # results in the data frame `res_hookreg`.
 
-res_hookreg <- sapply(2L:ncol(data), function(i) {
-    hookreg(x=data[, 1], y=data[, i])
-}) %>% t %>% data.frame(sample=colnames(data)[-1],.)
+res_hookreg <-  data.frame(sample=colnames(data)[-1], 
+                           t(sapply(2L:ncol(data), function(i) {
+                             hookreg(x=data[, 1], y=data[, i])
+                           })))
 
 # Fetch the calculated parameters from the calculations with the hookreg() 
 # function as a table `res_hookreg_table`.
@@ -137,7 +135,7 @@ print(xtable(res_hookreg_table,
 )
 
 ## ---- echo=TRUE, message=FALSE, warning=FALSE----------------------------
-# Note that the PCRedux package and the magrittr package need to be loaded (see above).
+# Note that the PCRedux package needs to be loaded (see above).
 # Load the qpcR package to prevent messages during the start.
 suppressMessages(library(qpcR))
 
@@ -146,9 +144,10 @@ suppressMessages(library(qpcR))
 # results in the data frame `res_hookregNL`.
 # Not that `suppressMessages()` to prevent warning messages from the qpcR package.
 
-res_hookregNL <- suppressMessages(sapply(2L:ncol(data), function(i) {
-    hookregNL(x=data[, 1], y=data[, i])
-}) %>% t %>% data.frame(sample=colnames(data)[-1],.))
+res_hookregNL <- data.frame(sample=colnames(data)[-1],
+                            t(suppressMessages(sapply(2L:ncol(data), function(i) {
+                              hookregNL(x=data[, 1], y=data[, i])
+                            }))))
 
 res_hookregNL_table <- data.frame(sample=as.character(res_hookregNL[["sample"]]),
                                   slope=signif(as.numeric(res_hookregNL[["slope"]]), 1),
@@ -180,9 +179,6 @@ print(xtable(res_hookregNL_table,
 
 library(readxl)
 
-# The dplyr package was used for data manipulation.
-library(dplyr)
-
 # Read the data as EXCEL file.
 Table_human_rated <- read_xlsx(path=system.file("Table_human_rated.xlsx", 
                                                 package="PCRedux"))
@@ -206,7 +202,7 @@ colnames(res) <- c("Sample",
 # curvature, if either the hookreg() or hookregNL() function are positive.
 
 meta_hookreg <- sapply(1:nrow(res), function(i){
-    ifelse(res[i, "hookreg"] == 1 || res[i, "hookregNL"] == 1, 1, 0)
+  ifelse(res[i, "hookreg"] == 1 || res[i, "hookregNL"] == 1, 1, 0)
 })
 
 res_out <- data.frame(Sample=res[["Sample"]], res[["Human rater"]], 
@@ -227,17 +223,17 @@ options(xtable.comment=FALSE)
 print(xtable(res_out, digits=0, 
              caption = "Aggregated decisions from the human classification and 
 the results from the machine decision of the hookreg() and hookregNL() 
-functions.", label='method_comparision'), ,
-      caption.placement = "top",
-      scalebox='0.65')
+functions.", label='method_comparison'), 
+caption.placement = "top",
+scalebox='0.65')
 
 ## ----echo=TRUE, message=FALSE, warning=FALSE-----------------------------
-res_performeR <- rbind(
-    hookreg=performeR(res_out[["hookreg"]], res_out[["Human rater"]]),
-                       hookregNL=performeR(res_out[["hookregNL"]], res_out[["Human rater"]]),
-                       combined_hookreg=performeR(res_out[["hookreg and hoohkreNL combined"]], 
-                                                  res_out[["Human rater"]])
-) %>% t %>% signif(4)
+res_performeR <- signif(t(rbind(
+  hookreg=performeR(res_out[["hookreg"]], res_out[["Human rater"]]),
+  hookregNL=performeR(res_out[["hookregNL"]], res_out[["Human rater"]]),
+  combined_hookreg=performeR(res_out[["hookreg and hoohkreNL combined"]], 
+                             res_out[["Human rater"]])
+)), 4)
 
 colnames(res_performeR) <- c("hookreg", "hookregNL", "hookreg and hookregNL")
 
@@ -255,11 +251,11 @@ TPR; Specificity, SPC; Precision, PPV; Negative predictive value, NPV; Fall-out,
 FPR; False negative rate, FNR; False discovery rate, FDR; Accuracy, ACC; F1 
 score, F1; Matthews correlation coefficient, MCC, Cohen's kappa (binary 
 classification), $\\kappa$", label='res_performeR'),
-      size = "normalsize",
-      include.rownames = TRUE,
-      include.colnames = TRUE,
-      caption.placement = "top",
-      comment=FALSE,
-      table.placement = "!ht", scalebox='0.75'
+size = "normalsize",
+include.rownames = TRUE,
+include.colnames = TRUE,
+caption.placement = "top",
+comment=FALSE,
+table.placement = "!ht", scalebox='0.75'
 )
 
